

function OnFinish(selProj, selObj)
{
	try
	{
		var strProjectPath = wizard.FindSymbol('PROJECT_PATH');
		var strProjectName = wizard.FindSymbol('PROJECT_NAME');

		selProj = CreateCustomProject(strProjectName, strProjectPath);
		AddConfig(selProj, strProjectName);
		AddFilters(selProj);

		var InfFile = CreateCustomInfFile();
		CreateRenderParams();
		AddFilesToCustomProj(selProj, strProjectName, strProjectPath, InfFile);
		PchSettings(selProj);
		InfFile.Delete();

		selProj.Object.Save();
	}
	catch(e)
	{
		if (e.description.length != 0)
			SetErrorInfo(e);
		return e.number
	}
}

function CreateRenderParams()
{
    try
    {
        
        var ChannelName = wizard.FindSymbol('PROJECT_NAME');
        wizard.AddSymbol("CHANNEL_NAME", ChannelName);
        wizard.AddSymbol("CHANNEL_NAME_DEFINE", ChannelName.toUpperCase());
        wizard.AddSymbol("CHANNEL_EXPORTS", ChannelName.toUpperCase()+"_EXPORTS");
        
        var ChannelBaseClass = "A3d_Channel";
        wizard.AddSymbol("CHANNEL_BASE_CLASS", ChannelBaseClass);
        
//        var newGuid = Guid.NewGuid();
//        wizard.AddSymbol("CHANNEL_GUID_STRUCT", newGuid.ToByteArray().ToString());
//        wizard.AddSymbol("CHANNEL_GUID_COMMENT", newGuid.GetHashCode());

    }
    catch(e)
    {
   		if (e.description.length != 0)
			SetErrorInfo(e);
		return e.number
    }
}

function CreateCustomProject(strProjectName, strProjectPath)
{
	try
	{
		var strProjTemplatePath = wizard.FindSymbol('PROJECT_TEMPLATE_PATH');
		var strProjTemplate = '';
		strProjTemplate = strProjTemplatePath + '\\default.vcproj';

		var Solution = dte.Solution;
		var strSolutionName = "";
		if (wizard.FindSymbol("CLOSE_SOLUTION"))
		{
			Solution.Close();
			strSolutionName = wizard.FindSymbol("VS_SOLUTION_NAME");
			if (strSolutionName.length)
			{
				var strSolutionPath = strProjectPath.substr(0, strProjectPath.length - strProjectName.length);
				Solution.Create(strSolutionPath, strSolutionName);
			}
		}

		var strProjectNameWithExt = '';
		strProjectNameWithExt = strProjectName + '.vcproj';

		var oTarget = wizard.FindSymbol("TARGET");
		var prj;
		if (wizard.FindSymbol("WIZARD_TYPE") == vsWizardAddSubProject)  // vsWizardAddSubProject
		{
			var prjItem = oTarget.AddFromTemplate(strProjTemplate, strProjectNameWithExt);
			prj = prjItem.SubProject;
		}
		else
		{
			prj = oTarget.AddFromTemplate(strProjTemplate, strProjectPath, strProjectNameWithExt);
		}
		var fxtarget = wizard.FindSymbol("TARGET_FRAMEWORK_VERSION");
		if (fxtarget != null && fxtarget != "")
		{
		    fxtarget = fxtarget.split('.', 2);
		    if (fxtarget.length == 2)
			prj.Object.TargetFrameworkVersion = parseInt(fxtarget[0]) * 0x10000 + parseInt(fxtarget[1])
		}
		
		var prjGUID = prj.Object.ProjectGUID;
		wizard.AddSymbol("CHANNEL_GUID_COMMENT", prjGUID);
		
		prjGUID = prjGUID.substr(1, prjGUID.length-2);
		prjGUID = prjGUID.split('-');
		prjGUID[3] += prjGUID[4];
		var prjGUIDstruct = "{ 0x"+prjGUID[0]+", 0x"+prjGUID[1]+", 0x"+prjGUID[2]+", { 0x";
		for (var i=0; i<7; i++)
		{
		    prjGUIDstruct += prjGUID[3].substr(i*2, 2) + ", 0x";
		}
		prjGUIDstruct += prjGUID[3].substr(14, 2) + " } }";
		
        wizard.AddSymbol("CHANNEL_GUID_STRUCT", prjGUIDstruct);
		
		return prj;
	}
	catch(e)
	{
		throw e;
	}
}

function AddFilters(proj)
{
	try
	{
		//    
		var group = proj.Object.AddFilter('Source Files');
		group.Filter = "cpp";

		group = proj.Object.AddFilter('Header Files');
		group.Filter = "h";

	}
	catch(e)
	{
		throw e;
	}
}

function AddConfig(proj, strProjectName)
{
	try
	{
		var config = proj.Object.Configurations('Debug');
		config.IntermediateDirectory = '.\\Debug';
		config.OutputDirectory = '.\\Debug';
		config.ConfigurationType="2";
		config.InheritedPropertySheets="$(VCInstallDir)VCProjectDefaults\UpgradeFromVC71.vsprops";
		config.UseOfMFC="0";
		config.ATLMinimizesCRunTimeLibraryUsage="false";
		config.CharacterSet="2";


		var CLTool = config.Tools('VCCLCompilerTool');
		CLTool.PreprocessorDefinitions="WIN32;_DEBUG;_WINDOWS;_USRDLL;_NDEBUG;"+strProjectName.toUpperCase()+"_EXPORTS";
		CLTool.UsePrecompiledHeader="1";
		CLTool.PrecompiledHeaderThrough="stdafx.h";
		CLTool.PrecompiledHeaderFile=".\\Debug/"+strProjectName+".pch";
		CLTool.DebugInformationFormat="4";

		var LinkTool = config.Tools('VCLinkerTool');
		LinkTool.AdditionalDependencies="highpoly.lib";
		LinkTool.OutputFile="Debug/"+strProjectName+".dll";
		LinkTool.LinkIncremental="2";
		LinkTool.GenerateDebugInformation="true";
		LinkTool.ProgramDatabaseFile="Debug/"+strProjectName+".pdb";
		LinkTool.SubSystem="2";
		LinkTool.ImportLibrary="Debug/"+strProjectName+".lib";



		config = proj.Object.Configurations('Release');
		config.IntermediateDirectory = '.\\Release';
		config.OutputDirectory = '.\\Release';
		config.ConfigurationType="2";
		config.InheritedPropertySheets="$(VCInstallDir)VCProjectDefaults\UpgradeFromVC71.vsprops";
		config.UseOfMFC="0";
		config.ATLMinimizesCRunTimeLibraryUsage="false";
		config.CharacterSet="2";
		
		var CLTool = config.Tools('VCCLCompilerTool');
		CLTool.PreprocessorDefinitions="WIN32;NDEBUG;_WINDOWS;_USRDLL;_NDEBUG;"+strProjectName.toUpperCase()+"_EXPORTS";
		CLTool.UsePrecompiledHeader="1";
		CLTool.PrecompiledHeaderThrough="stdafx.h";
		CLTool.PrecompiledHeaderFile=".\\Release/"+strProjectName+".pch";

		var LinkTool = config.Tools('VCLinkerTool');
		LinkTool.AdditionalDependencies="highpoly.lib";
		LinkTool.OutputFile="Release/"+strProjectName+".dll";
		LinkTool.LinkIncremental="2";
		LinkTool.ProgramDatabaseFile="Release/"+strProjectName+".pdb";
		LinkTool.SubSystem="2";
		LinkTool.ImportLibrary="Release/"+strProjectName+".lib";
	}
	catch(e)
	{
		throw e;
	}
}

function PchSettings(proj)
{
	// TODO:   pch
}

function DelFile(fso, strWizTempFile)
{
	try
	{
		if (fso.FileExists(strWizTempFile))
		{
			var tmpFile = fso.GetFile(strWizTempFile);
			tmpFile.Delete();
		}
	}
	catch(e)
	{
		throw e;
	}
}

function CreateCustomInfFile()
{
	try
	{
		var fso, TemplatesFolder, TemplateFiles, strTemplate;
		fso = new ActiveXObject('Scripting.FileSystemObject');

		var TemporaryFolder = 2;
		var tfolder = fso.GetSpecialFolder(TemporaryFolder);
		var strTempFolder = tfolder.Drive + '\\' + tfolder.Name;

		var strWizTempFile = strTempFolder + "\\" + fso.GetTempName();

		var strTemplatePath = wizard.FindSymbol('TEMPLATES_PATH');
		var strInfFile = strTemplatePath + '\\Templates.inf';
		wizard.RenderTemplate(strInfFile, strWizTempFile);

		var WizTempFile = fso.GetFile(strWizTempFile);
		return WizTempFile;
	}
	catch(e)
	{
		throw e;
	}
}

function GetTargetName(strName, strProjectName)
{
	try
	{
		// TODO:         
		var strTarget = strName;

		if (strName == 'Channel.h')
			strTarget = strProjectName+'.h';

		if (strName == 'Channel.cpp')
			strTarget = strProjectName+'.cpp';

		return strTarget;
	}
	catch(e)
	{
		throw e;
	}
}

function AddFilesToCustomProj(proj, strProjectName, strProjectPath, InfFile)
{
	try
	{
		var projItems = proj.ProjectItems

		var strTemplatePath = wizard.FindSymbol('TEMPLATES_PATH');

		var strTpl = '';
		var strName = '';

		var strTextStream = InfFile.OpenAsTextStream(1, -2);
		while (!strTextStream.AtEndOfStream)
		{
			strTpl = strTextStream.ReadLine();
			if (strTpl != '')
			{
				strName = strTpl;
				var strTarget = GetTargetName(strName, strProjectName);
				var strTemplate = strTemplatePath + '\\' + strTpl;
				var strFile = strProjectPath + '\\' + strTarget;

				var bCopyOnly = false;  //  "true"       strTemplate  strTarget,      
				var strExt = strName.substr(strName.lastIndexOf("."));
				if(strExt==".bmp" || strExt==".ico" || strExt==".gif" || strExt==".rtf" || strExt==".css")
					bCopyOnly = true;
				wizard.RenderTemplate(strTemplate, strFile, bCopyOnly);
				proj.Object.AddFile(strFile);
			}
		}
		strTextStream.Close();
	}
	catch(e)
	{
		throw e;
	}
}


// SIG // Begin signature block
// SIG // MIIbNwYJKoZIhvcNAQcCoIIbKDCCGyQCAQExCzAJBgUr
// SIG // DgMCGgUAMGcGCisGAQQBgjcCAQSgWTBXMDIGCisGAQQB
// SIG // gjcCAR4wJAIBAQQQEODJBs441BGiowAQS9NQkAIBAAIB
// SIG // AAIBAAIBAAIBADAhMAkGBSsOAwIaBQAEFMaLCekVnEQC
// SIG // p8Upx3mIeauHmJM6oIIWKjCCBBIwggL6oAMCAQICDwDB
// SIG // AIs8PIgR0T72Y+zfQDANBgkqhkiG9w0BAQQFADBwMSsw
// SIG // KQYDVQQLEyJDb3B5cmlnaHQgKGMpIDE5OTcgTWljcm9z
// SIG // b2Z0IENvcnAuMR4wHAYDVQQLExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xITAfBgNVBAMTGE1pY3Jvc29mdCBSb290
// SIG // IEF1dGhvcml0eTAeFw05NzAxMTAwNzAwMDBaFw0yMDEy
// SIG // MzEwNzAwMDBaMHAxKzApBgNVBAsTIkNvcHlyaWdodCAo
// SIG // YykgMTk5NyBNaWNyb3NvZnQgQ29ycC4xHjAcBgNVBAsT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEhMB8GA1UEAxMY
// SIG // TWljcm9zb2Z0IFJvb3QgQXV0aG9yaXR5MIIBIjANBgkq
// SIG // hkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqQK9wXDmO/JO
// SIG // Gyifl3heMOqiqY0lX/j+lUyjt/6doiA+fFGim6KPYDJr
// SIG // 0UJkee6sdslU2vLrnIYcj5+EZrPFa3piI9YdPN4PAZLo
// SIG // lsS/LWaammgmmdA6LL8MtVgmwUbnCj44liypKDmo7EmD
// SIG // QuOED7uabFVhrIJ8oWAtd0zpmbRkO5pQHDEIJBSfqeeR
// SIG // KxjmPZhjFGBYBWWfHTdSh/en75QCxhvTv1VFs4mAvzrs
// SIG // VJROrv2nem10Tq8YzJYJKCEAV5BgaTe7SxIHPFb/W/uk
// SIG // ZgoIptKBVlfvtjteFoF3BNr2vq6Alf6wzX/WpxpyXDzK
// SIG // vPAIoyIwswaFybMgdxOF3wIDAQABo4GoMIGlMIGiBgNV
// SIG // HQEEgZowgZeAEFvQcO9pcp4jUX4Usk2O/8uhcjBwMSsw
// SIG // KQYDVQQLEyJDb3B5cmlnaHQgKGMpIDE5OTcgTWljcm9z
// SIG // b2Z0IENvcnAuMR4wHAYDVQQLExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xITAfBgNVBAMTGE1pY3Jvc29mdCBSb290
// SIG // IEF1dGhvcml0eYIPAMEAizw8iBHRPvZj7N9AMA0GCSqG
// SIG // SIb3DQEBBAUAA4IBAQCV6AvAjfOXGDXtuAEk2HcR81xg
// SIG // Mp+eC8s+BZGIj8k65iHy8FeTLLWgR8hi7/zXzDs7Wqk2
// SIG // VGn+JG0/ycyq3gV83TGNPZ8QcGq7/hJPGGnA/NBD4xFa
// SIG // IE/qYnuvqhnIKzclLb5loRKKJQ9jo/dUHPkhydYV81Ks
// SIG // bkMyB/2CF/jlZ2wNUfa98VLHvefEMPwgMQmIHZUpGk3V
// SIG // HQKl8YDgA7Rb9LHdyFfuZUnHUlS2tAMoEv+Q1vAIj364
// SIG // l8WrNyzkeuSod+N2oADQaj/B0jaK4EESqDVqG2rbNeHU
// SIG // HATkqEUEyFozOG5NHA1itwqijNPVVD9GzRxVpnDbEjqH
// SIG // k3Wfp9KgMIIEYDCCA0ygAwIBAgIKLqsR3FD/XJ3LwDAJ
// SIG // BgUrDgMCHQUAMHAxKzApBgNVBAsTIkNvcHlyaWdodCAo
// SIG // YykgMTk5NyBNaWNyb3NvZnQgQ29ycC4xHjAcBgNVBAsT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEhMB8GA1UEAxMY
// SIG // TWljcm9zb2Z0IFJvb3QgQXV0aG9yaXR5MB4XDTA3MDgy
// SIG // MjIyMzEwMloXDTEyMDgyNTA3MDAwMFoweTELMAkGA1UE
// SIG // BhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNV
// SIG // BAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBD
// SIG // b3Jwb3JhdGlvbjEjMCEGA1UEAxMaTWljcm9zb2Z0IENv
// SIG // ZGUgU2lnbmluZyBQQ0EwggEiMA0GCSqGSIb3DQEBAQUA
// SIG // A4IBDwAwggEKAoIBAQC3eX3WXbNFOag0rDHa+SU1SXfA
// SIG // +x+ex0Vx79FG6NSMw2tMUmL0mQLDTdhJbC8kPmW/ziO3
// SIG // C0i3f3XdRb2qjw5QxSUr8qDnDSMf0UEk+mKZzxlFpZNK
// SIG // H5nNsy8iw0otfG/ZFR47jDkQOd29KfRmOy0BMv/+J0im
// SIG // tWwBh5z7urJjf4L5XKCBhIWOsPK4lKPPOKZQhRcnh07d
// SIG // MPYAPfTG+T2BvobtbDmnLjT2tC6vCn1ikXhmnJhzDYav
// SIG // 8sTzILlPEo1jyyzZMkUZ7rtKljtQUxjOZlF5qq2HyFY+
// SIG // n4JQiG4FsTXBeyS9UmY9mU7MK34zboRHBtGe0EqGAm6G
// SIG // AKTAh99TAgMBAAGjgfowgfcwEwYDVR0lBAwwCgYIKwYB
// SIG // BQUHAwMwgaIGA1UdAQSBmjCBl4AQW9Bw72lyniNRfhSy
// SIG // TY7/y6FyMHAxKzApBgNVBAsTIkNvcHlyaWdodCAoYykg
// SIG // MTk5NyBNaWNyb3NvZnQgQ29ycC4xHjAcBgNVBAsTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEhMB8GA1UEAxMYTWlj
// SIG // cm9zb2Z0IFJvb3QgQXV0aG9yaXR5gg8AwQCLPDyIEdE+
// SIG // 9mPs30AwDwYDVR0TAQH/BAUwAwEB/zAdBgNVHQ4EFgQU
// SIG // zB3OdgBwW6/x2sROmlFELqNEY/AwCwYDVR0PBAQDAgGG
// SIG // MAkGBSsOAwIdBQADggEBAHurrn5KJvLOvE50olgndCp1
// SIG // s4b9q0yUeABN6crrGNxpxQ6ifPMCQ8bKh8z4U8zCn71W
// SIG // b/BjRKlEAO6WyJrVHLgLnxkNlNfaHq0pfe/tpnOsj945
// SIG // jj2Yarw4bdKIryP93+nWaQmRiL3+4QC7NPP3fPkQEi4F
// SIG // 6ymWk0JrKHG3OI/gBw3JXWjNvYBBa2aou7e7jjTK8gMQ
// SIG // fHr10uBC33v+4eGs/vbf1Q2zcNaS40+2OKJ8LdQ92zQL
// SIG // YjcCn4FqI4n2XGOPsFq7OddgjFWEGjP1O5igggyiX4uz
// SIG // LLehpcur2iC2vzAZhSAUDSq8UvRB4F4w45IoaYfBcOLz
// SIG // p6vOgEJydg4wggRqMIIDUqADAgECAgphD3hNAAAAAAAD
// SIG // MA0GCSqGSIb3DQEBBQUAMHkxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xIzAhBgNVBAMTGk1pY3Jvc29mdCBDb2RlIFNpZ25p
// SIG // bmcgUENBMB4XDTA3MDgyMzAwMjMxM1oXDTA5MDIyMzAw
// SIG // MzMxM1owdDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEeMBwGA1UE
// SIG // AxMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMIIBIjANBgkq
// SIG // hkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAotsKjc/CwUmb
// SIG // zao6NK0jWWvbbL4hIreUyOquv8bVJsIyEYu82l0s+zZW
// SIG // HhUrro8N3RSjbihMfxY/QayNQLFGiA3ZgZStlwbQV0R2
// SIG // XOrx/A7if3SjM8t05e/jYaF+A7dF/9U+EtWwyl4N0Hvy
// SIG // txMN/GBqKIV1jLetvIXoF7SQvvUWtmJd7RHfOu4hW4uv
// SIG // gHPDReOViXdgm+etd8E3jTMULxPbYsmuGqlPmGet1CA5
// SIG // MHHgjWdG4sYc9A1QdEEv6AUkaiFrSbCSxLI5x0KlbVwY
// SIG // SquP146DPngKR9iksoQjw+Lye2axSnS9JkFLnGEUYE4w
// SIG // yILz0AtwfO5VTXfSCFV2gQIDAQABo4H4MIH1MA4GA1Ud
// SIG // DwEB/wQEAwIGwDAdBgNVHQ4EFgQU8yFAjnxR+FRLmOUX
// SIG // 12qDNAUuJugwEwYDVR0lBAwwCgYIKwYBBQUHAwMwHwYD
// SIG // VR0jBBgwFoAUzB3OdgBwW6/x2sROmlFELqNEY/AwRAYD
// SIG // VR0fBD0wOzA5oDegNYYzaHR0cDovL2NybC5taWNyb3Nv
// SIG // ZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvQ1NQQ0EuY3Js
// SIG // MEgGCCsGAQUFBwEBBDwwOjA4BggrBgEFBQcwAoYsaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9D
// SIG // U1BDQS5jcnQwDQYJKoZIhvcNAQEFBQADggEBAEBXb1Nn
// SIG // niCDNAEO5hdLPK3r2IF/7g15dHdPl0cY8wAVaX7bYpCi
// SIG // /WehnOQoKfpV15n+UL9eCbO5pu2C85geb1n69fHhDNOL
// SIG // CD4WFyDRwLVFRwgmYFcJS5TwCMy6TW7w4kgSKDWLIXLf
// SIG // X7avaRIklO7pNAnbfm5vkgpSyipMSaoyLIboocxdJry8
// SIG // POBbsoMLujUcT4RFR/+7lKFZB6mW3Xi9V3+lp07M8q2c
// SIG // mkHiy1wkPtx/NEdO9s/Ie53rtsmcYxRTr62a79e/z6Ch
// SIG // q5XKeiuHLMDH2fxsA9q/OK3x0VwZFw/A98qAphAIGt2Q
// SIG // I+ewoUw+6rARJngOwSy5pGvHjzwwggSdMIIDhaADAgEC
// SIG // AgphSXztAAAAAAAFMA0GCSqGSIb3DQEBBQUAMHkxCzAJ
// SIG // BgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
// SIG // DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3Nv
// SIG // ZnQgQ29ycG9yYXRpb24xIzAhBgNVBAMTGk1pY3Jvc29m
// SIG // dCBUaW1lc3RhbXBpbmcgUENBMB4XDTA2MDkxNjAxNTUy
// SIG // MloXDTExMDkxNjAyMDUyMlowgaYxCzAJBgNVBAYTAlVT
// SIG // MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
// SIG // ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9y
// SIG // YXRpb24xJzAlBgNVBAsTHm5DaXBoZXIgRFNFIEVTTjox
// SIG // MEQ4LTU4NDctQ0JGODEnMCUGA1UEAxMeTWljcm9zb2Z0
// SIG // IFRpbWVzdGFtcGluZyBTZXJ2aWNlMIIBIjANBgkqhkiG
// SIG // 9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6roFY8jZea6ERD6l
// SIG // s8TtTJ4k3zl2HgnWMkpYeNIr2aUHkO/nPfu9Jnyj++V9
// SIG // fjLP2T2LOTfy+Ng7NBbUkoL7NOxohXIaj+C4TOC4hfMz
// SIG // CgLBonZzNUxd8bfhSn0duJR42/8ehRVCRnHOfydXEtGD
// SIG // TzvP+t72i+0/AOPV3mH5F41LpIE89WlA6uGJvwdPunR7
// SIG // 6QzlR+qrbPHVZ4EI+BbKfRO7c+IJTPpi++2gOZo6/usR
// SIG // yGEeYljYClSD1TtLS+JVvS9gGo6SBUPaXeuCCiOXCaAF
// SIG // MWWLk04eQSGikpD9RURFbzWxRTetaall+TRDsRfCOznh
// SIG // EIzyGofjVFAfO50xrQIDAQABo4H4MIH1MB0GA1UdDgQW
// SIG // BBR+cvAuP1Yp4CX3aLgB/Evhfs/jPjAfBgNVHSMEGDAW
// SIG // gBRv6E4/l7k0q0uGj7yc6qw7QUPG0DBEBgNVHR8EPTA7
// SIG // MDmgN6A1hjNodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20v
// SIG // cGtpL2NybC9wcm9kdWN0cy90c3BjYS5jcmwwSAYIKwYB
// SIG // BQUHAQEEPDA6MDgGCCsGAQUFBzAChixodHRwOi8vd3d3
// SIG // Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL3RzcGNhLmNy
// SIG // dDATBgNVHSUEDDAKBggrBgEFBQcDCDAOBgNVHQ8BAf8E
// SIG // BAMCBsAwDQYJKoZIhvcNAQEFBQADggEBAGl6ggkMFtHe
// SIG // z0aJLr/RNHqBfycoQSrz0yGSDpetX1NeKfntwVRKqH33
// SIG // E9ALFPlN8oYVAG7jgx0oRacsOTLdb5o3Wu4jUo9UA40/
// SIG // p5xkOPY2yBRDtjo+mMkNw3GBKPNmpzHiXF2P+VJS4Vzr
// SIG // k5CdaQlMidHRdkw0DWrhfESnK1uDVH9FJBklxIpGxSXj
// SIG // GYBpKRT2F8bwIiyBRl4r9Pmmxnc+I2/5pmSFjqJiDakt
// SIG // HqjlkD5//7CO/Jfs8f0Er81Jzlp0rPrzEx8bOc6jtNa8
// SIG // 9LTuyK3yVh77PPHI1ipEvL+cP31mGM2yIGMKykA9ZTIZ
// SIG // fLK4PcEmSE4iGZlujDDB8ZEwggSdMIIDhaADAgECAhBq
// SIG // C5lPwAAlqxHbRR9YemeiMA0GCSqGSIb3DQEBBQUAMHAx
// SIG // KzApBgNVBAsTIkNvcHlyaWdodCAoYykgMTk5NyBNaWNy
// SIG // b3NvZnQgQ29ycC4xHjAcBgNVBAsTFU1pY3Jvc29mdCBD
// SIG // b3Jwb3JhdGlvbjEhMB8GA1UEAxMYTWljcm9zb2Z0IFJv
// SIG // b3QgQXV0aG9yaXR5MB4XDTA2MDkxNjAxMDQ0N1oXDTE5
// SIG // MDkxNTA3MDAwMFoweTELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
// SIG // HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEj
// SIG // MCEGA1UEAxMaTWljcm9zb2Z0IFRpbWVzdGFtcGluZyBQ
// SIG // Q0EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB
// SIG // AQDcN277r8hCSnEYyM5IPlPA+qsUuiwyuxJPUsiD7T4z
// SIG // 2Ukxkii2kWTgH1CEusJL0X8F+O91vovHqNWuaXBmeCdm
// SIG // 6La374W5ze6q/RKkC1kiKS/PQNlWBBt2tW1kbUpU293x
// SIG // 3r+fg8eA339MAjeU9cCeCFYeaEfN2cB2XC99tiUEtFZb
// SIG // ahxj/4B8PO7VBCVNOXd0B13CXNiGNyx1yQ7qHjkJfHb+
// SIG // nWxueuDsPo+XnnEOXypPGGJgMp7Sg04rIlxoRYveL4QQ
// SIG // ULL5tRqNbO4lmxP4yxDXhQ70gnZzNsaVeqLMYAbsBbCG
// SIG // M7f4lFuEQYRYhZRusB8sSMxvnEPgauh/Jo5rAgMBAAGj
// SIG // ggEoMIIBJDATBgNVHSUEDDAKBggrBgEFBQcDCDCBogYD
// SIG // VR0BBIGaMIGXgBBb0HDvaXKeI1F+FLJNjv/LoXIwcDEr
// SIG // MCkGA1UECxMiQ29weXJpZ2h0IChjKSAxOTk3IE1pY3Jv
// SIG // c29mdCBDb3JwLjEeMBwGA1UECxMVTWljcm9zb2Z0IENv
// SIG // cnBvcmF0aW9uMSEwHwYDVQQDExhNaWNyb3NvZnQgUm9v
// SIG // dCBBdXRob3JpdHmCDwDBAIs8PIgR0T72Y+zfQDAQBgkr
// SIG // BgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQUb+hOP5e5NKtL
// SIG // ho+8nOqsO0FDxtAwGQYJKwYBBAGCNxQCBAweCgBTAHUA
// SIG // YgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQFMAMB
// SIG // Af8wDQYJKoZIhvcNAQEFBQADggEBAJRNETHCfFC7EY6h
// SIG // YQcBDoxwRY3vc1S9PwkFLf+4UVOFHO05kbejVgvejLY7
// SIG // G9H7rKfJt7FRIRtvCGl+awOiIkbtbLRtfCK4RtOE840P
// SIG // vgeKNsHrfulwXUWfktLMzt2OwOG/Ks187MmuMtWHuctj
// SIG // xDbRGCG/dt47mrMbc54hiNi0tBJUjPScwmVKmigmnGCK
// SIG // DzvHE2V4SLvPrYM6T7BiWN4w6ek5HeOJ8to5gfkTIYxk
// SIG // gGMGBJbymgJDL3tGiLr/Atll+Ure2gN0k7MFbgzMndwo
// SIG // YXxI8RecESE4AhyHrAbFljK45UDGUz29qYne6GY3jfQi
// SIG // lpzMsHdUUTrWckSyI/YxggR5MIIEdQIBATCBhzB5MQsw
// SIG // CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
// SIG // MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
// SIG // b2Z0IENvcnBvcmF0aW9uMSMwIQYDVQQDExpNaWNyb3Nv
// SIG // ZnQgQ29kZSBTaWduaW5nIFBDQQIKYQ94TQAAAAAAAzAJ
// SIG // BgUrDgMCGgUAoIGkMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMCMGCSqGSIb3DQEJBDEWBBRcE3SZRUJmj4/R4nPA
// SIG // /vleLKmCATBEBgorBgEEAYI3AgEMMTYwNKAagBgAYwB1
// SIG // AHMAdABvAG0AdwBpAHoALgBqAHOhFoAUaHR0cDovL21p
// SIG // Y3Jvc29mdC5jb20wDQYJKoZIhvcNAQEBBQAEggEAh+4i
// SIG // yIwUMbGJPdKGsZ9k4gGdG1673oSrPheZ/Pc6Aaf8qhMF
// SIG // pMRLpdpsZv7cEgZEdDQ7LeLW7UKxauKRU7ZthtUd5Hga
// SIG // jKqpGvBkMVYqfaqZHUhgPR/yjkV4b7l0GKrDXcAejmhM
// SIG // vITUmqfjQsNcXUF94e6vinh90eGz3j+ES2quWuMKl7QO
// SIG // doobl7LZhXOo9MN0Q+F/Xv2AgSe1l/ciTeIZUzHwpkvv
// SIG // awRkvX15xCZiHaSqG/LNyW8zrXX/4xw4dJa3gsUE5TVr
// SIG // Wf1GEHKZACALc/cLeNnZhLS6KdefjZmVLzyD+cJ2cS+p
// SIG // wlnkqfZ6DqwVtSSWeAkDaYDCcWuAj6GCAh8wggIbBgkq
// SIG // hkiG9w0BCQYxggIMMIICCAIBATCBhzB5MQswCQYDVQQG
// SIG // EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
// SIG // BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
// SIG // cnBvcmF0aW9uMSMwIQYDVQQDExpNaWNyb3NvZnQgVGlt
// SIG // ZXN0YW1waW5nIFBDQQIKYUl87QAAAAAABTAHBgUrDgMC
// SIG // GqBdMBgGCSqGSIb3DQEJAzELBgkqhkiG9w0BBwEwHAYJ
// SIG // KoZIhvcNAQkFMQ8XDTA4MTAwOTAzMzA1NVowIwYJKoZI
// SIG // hvcNAQkEMRYEFCKugGx28AsxPS4nChqNwlowaeSdMA0G
// SIG // CSqGSIb3DQEBBQUABIIBAGnYyFasfODMhlFtWLIVpzOq
// SIG // xAO2s+xQ6Onr/ExBQutvZKmyaOENYgTJRZ6JO22PUxq9
// SIG // PIqoa6Q9EK1ubUuEGC9aaop9ET6SFHliDb4KRg5859AP
// SIG // IGseHm8IyDJemYZlsA0Og+TgSmfok2RF4bmxWBpPWGCk
// SIG // A+umEr6Er3s7Pm7xn1MRnz+RZl22nNFCeMtlbBtNsfIk
// SIG // BxEJAoipel/nvwMAWPdtUy4DaX95Ap4ezvpZKKnn2QmL
// SIG // ZvkmHOukuBh3sokduvXMBodVWQPHOhP04GuvmABTZack
// SIG // Rc0Ur5CdYxhN3c6djT2t+Bs56USzj28qVt4DnrHQG/GW
// SIG // NNxJPF1GJiY=
// SIG // End signature block
